@@ -1,7 +1,7 @@
 package App::reposdb;
 
 our $DATE = '2016-06-12'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,6 +9,22 @@ use warnings;
 
 our %SPEC;
 
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'Manipulate repos.db',
+    description => <<'_',
+
+`repos.db` is a SQLite database that lists repository names along with some
+extra data. They have various uses, but my first use-case for this is to store
+last commit/status/pull time (updated via a post-commit git hook or `gitwrap`).
+This is useful to speed up like syncing of repositories in `Git::Bunch` that
+wants to find out which of the hundreds/thousand+ git repositories are "the most
+recently used" to prioritize these repositories first. Using information from
+`repos.db` is faster than having to `git status` or even stat() each repository.
+
+_
+};
+
 our $db_schema_spec = {
     latest_v => 2,
     install_v1 => [
@@ -94,9 +110,12 @@ $SPEC{list_repos} = {
     summary => 'List repositories registered in repos.db',
     args => {
         %common_args,
-        sort => {
-            schema => ['str*', in=>[qw/name -name commit_time -commit_time status_time -status_time pull_time -pull_time/]],
-            default => 'name',
+        sorts => {
+            'x.name.is_plural' => 1,
+            schema => ['array*', {
+                of => ['str*', in=>[qw/name -name commit_time -commit_time status_time -status_time pull_time -pull_time/]]
+            }],
+            default => ['name'],
         },
         detail => {
             schema => 'bool',
@@ -110,11 +129,16 @@ sub list_repos {
     _set_args_default(\%args);
     my $dbh = _connect_db(\%args);
 
-    my @res;
-    $args{sort} =~ /\A(-)?(\w+)\z/ or return [400, "Invalid sort order"];
-    my $sth = $dbh->prepare("SELECT * FROM repos ORDER BY $2".
-                                ($1 ? " DESC":""));
+    my @orders;
+    for my $sort (@{ $args{sorts} }) {
+        $sort =~ /\A(-)?(\w+)\z/ or return [400, "Invalid sort order `$sort`"];
+        push @orders, $2 . ($1 ? " DESC":"");
+    }
+    my $sql = "SELECT * FROM repos ORDER BY ".join(", ", @orders);
+
+    my $sth = $dbh->prepare($sql);
     $sth->execute;
+    my @res;
     while (my $row = $sth->fetchrow_hashref) {
         push @res, $row;
     }
@@ -123,6 +147,8 @@ sub list_repos {
     if ($args{detail}) {
         $resmeta->{'table.fields'} =
             [qw/name commit_time status_time pull_time/];
+        $resmeta->{'table.field_formats'} =
+            [undef, qw/iso8601_datetime iso8601_datetime iso8601_datetime/];
     } else {
         @res = map { $_->{name} } @res;
     }
@@ -181,7 +207,7 @@ sub touch_repo {
 }
 
 1;
-# ABSTRACT: Utility to manipulate repos.db
+# ABSTRACT: Manipulate repos.db
 
 __END__
 
@@ -191,11 +217,11 @@ __END__
 
 =head1 NAME
 
-App::reposdb - Utility to manipulate repos.db
+App::reposdb - Manipulate repos.db
 
 =head1 VERSION
 
-This document describes version 0.002 of App::reposdb (from Perl distribution App-reposdb), released on 2016-06-12.
+This document describes version 0.003 of App::reposdb (from Perl distribution App-reposdb), released on 2016-06-12.
 
 =head1 SYNOPSIS
 
@@ -203,6 +229,15 @@ See L<reposdb>.
 
 =head1 DESCRIPTION
 
+
+C<repos.db> is a SQLite database that lists repository names along with some
+extra data. They have various uses, but my first use-case for this is to store
+last commit/status/pull time (updated via a post-commit git hook or C<gitwrap>).
+This is useful to speed up like syncing of repositories in C<Git::Bunch> that
+wants to find out which of the hundreds/thousand+ git repositories are "the most
+recently used" to prioritize these repositories first. Using information from
+C<repos.db> is faster than having to C<git status> or even stat() each repository.
+
 =head1 FUNCTIONS
 
 
@@ -220,7 +255,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<reposdb_path>* => I<str>
 
-=item * B<sort> => I<str> (default: "name")
+=item * B<sorts> => I<array[str]> (default: ["name"])
 
 =back
 
